@@ -104,7 +104,9 @@ namespace {
             for (; line < end; line++) {
                 QString buffer = snap.line(line);
                 replaceInvalidUtf16ForRegexSearch(buffer, 0);
-                buffer += QStringLiteral("\n");
+                if (line + 1 < snap.lineCount()) {
+                    buffer += QStringLiteral("\n");
+                }
                 int foldedLine = line;
                 QRegularExpressionMatchIterator remi
                         = regex.globalMatch(buffer, 0,
@@ -121,7 +123,9 @@ namespace {
                         foldedLine += 1;
                         buffer += snap.line(foldedLine);
                         replaceInvalidUtf16ForRegexSearch(buffer, cont);
-                        buffer += QStringLiteral("\n");
+                        if (foldedLine + 1 < snap.lineCount()) {
+                            buffer += QStringLiteral("\n");
+                        }
                         remi = regex.globalMatch(buffer, 0,
                                                  foldedLine + 1 < snap.lineCount() ? QRegularExpression::MatchType::PartialPreferFirstMatch
                                                                                    : QRegularExpression::MatchType::NormalMatch,
@@ -265,7 +269,9 @@ namespace {
                 }
 
                 buffer += snap.line(i);
-                buffer += QStringLiteral("\n");
+                if (i + 1 < snap.lineCount()) {
+                    buffer += QStringLiteral("\n");
+                }
 
                 if (canceler.isCanceled()) {
                     return noMatch(snap);
@@ -476,7 +482,7 @@ namespace {
             if (start.hasSelection()) {
                 if (options & ZDocument::FindFlag::FindWrap || startLine > 0 || startCodeUnit > 1) {
                     startCodeUnit = startCodeUnit - 1;
-                    if (startCodeUnit <= 0) {
+                    if (startCodeUnit < 0) {
                         if (--startLine < 0) {
                             startLine = doc->lineCount() - 1;
                         }
