@@ -431,7 +431,11 @@ bool ZTerminalPrivate::commonInitForInternalConnection(ZTerminal::Options option
 
     struct winsize s;
     if (isatty(fd_read) && ioctl(fd_read, TIOCGWINSZ, &s) >= 0) {
-        termpaint_surface_resize(surface, s.ws_col, s.ws_row);
+        if (options.testFlag(ZTerminal::Inline)) {
+            termpaint_surface_resize(surface, s.ws_col, std::min(inlineHeight, (int)s.ws_row));
+        } else {
+            termpaint_surface_resize(surface, s.ws_col, s.ws_row);
+        }
     } else {
         termpaint_surface_resize(surface, 80, 24);
     }
@@ -518,10 +522,7 @@ bool ZTerminalPrivate::commonInitForInternalConnection(ZTerminal::Options option
                         if (p->options.testFlag(ZTerminal::DisableAutoResize)) {
                             return;
                         }
-                        struct winsize s;
-                        if (isatty(p->fd_read) && ioctl(p->fd_read, TIOCGWINSZ, &s) >= 0) {
-                            systemTerminal->resize(s.ws_col, s.ws_row);
-                        }
+                        p->updateSizeForInternalConnection();
                     }
                 });
             }
@@ -569,6 +570,17 @@ bool ZTerminalPrivate::commonInitForInternalConnection(ZTerminal::Options option
     return true;
 }
 
+void ZTerminalPrivate::updateSizeForInternalConnection() {
+    struct winsize s;
+    if (isatty(fd_read) && ioctl(fd_read, TIOCGWINSZ, &s) >= 0) {
+        if (options.testFlag(ZTerminal::Inline)) {
+            pub()->resize(s.ws_col, std::min(inlineHeight, (int)s.ws_row));
+        } else {
+            pub()->resize(s.ws_col, s.ws_row);
+        }
+    }
+}
+
 void ZTerminalPrivate::pauseTerminalForInternalConnection() {
     tcgetattr(fd_read, &prepauseTerminalAttributes);
 
