@@ -67,7 +67,12 @@ static auto parseSearchInfo(const QString &input) {
         } else {
             if (matchesMap[id].foundEnd.line == line) {
                 REQUIRE(matchesMap[id].foundEnd.codeUnit == codeUnit);
-                matchesMap[id].foundEnd.codeUnit = codeUnit + 1;
+                if (codeUnit == lines.back().size()) {
+                    matchesMap[id].foundEnd.line = line + 1;
+                    matchesMap[id].foundEnd.codeUnit = 0;
+                } else {
+                    matchesMap[id].foundEnd.codeUnit = codeUnit + 1;
+                }
             } else {
                 REQUIRE(matchesMap[id].foundEnd.line + 1 == line);
                 REQUIRE(codeUnit == 0);
@@ -979,6 +984,44 @@ TEST_CASE("regex search") {
 
     }
 
+    SECTION("literal-linebreak") {
+        static auto testCases = generateTestCases(R"(
+                                                  0|some Text
+                                                   >         1
+                                                  1|same Thing
+                                                   >          2
+                                                  2|aaaa bbbb
+                                              )");
+
+        auto testCase = GENERATE(from_range(testCases));
+
+        runChecks(testCase, QRegularExpression("\\n"), Qt::CaseSensitive,
+                {
+                      {"1", MatchCaptures{ {"\n"}, {}}},
+                      {"2", MatchCaptures{ {"\n"}, {}}},
+                      {"3", MatchCaptures{ {"\n"}, {}}}
+                });
+
+    }
+
+    SECTION("multi-linebreak") {
+        static auto testCases = generateTestCases(R"(
+                                                  0|some Text
+                                                   >         1
+                                                  1|same Thing
+                                                   >11111111111
+                                                  2|aaaa bbbb
+                                              )");
+
+        auto testCase = GENERATE(from_range(testCases));
+
+        runChecks(testCase, QRegularExpression("\\n.*\\n"), Qt::CaseSensitive,
+                {
+                      {"1", MatchCaptures{ {"\nsame Thing\n"}, {}}},
+                });
+
+    }
+
     SECTION("literal astral") {
         static auto testCases = generateTestCases(R"(
                                                   0|some Text
@@ -1447,6 +1490,26 @@ TEST_CASE("regex search") {
 
     }
 
+
+    SECTION("backward literal-newline") {
+        static auto testCases = generateTestCasesBackward(R"(
+                                                  0|some Text
+                                                   >         1
+                                                  1|same Thing
+                                                   >          2
+                                                  2|aaaa bbbb
+                                              )");
+
+        auto testCase = GENERATE(from_range(testCases));
+
+        runChecksBackward(testCase, QRegularExpression("\\n"), Qt::CaseSensitive,
+        {
+              {"1", MatchCaptures{ {"\n"}, {}}},
+              {"2", MatchCaptures{ {"\n"}, {}}},
+        });
+
+    }
+
     SECTION("backward one char t - mismatched case") {
         static auto testCases = generateTestCasesBackward(R"(
                                                   0|Test
